=======
History
=======

******************
1.0.0 (2026-03-03)
******************

* definition for base model and analyzers
* configuration handling for connections
* analyzers ready for text processing
* basic model with automatic created_at and updated_at fields

******************
0.0.1 (2026-03-03)
******************

* First release on PyPI.
